@@ -21,6 +21,8 @@ cat Scripts.txt |\
           uniq --skip-chars=13 |\
            #Remove ends of ranges
            sed 's,\.\......,,' |\
+            #Remove underscores
+            sed 's,_, ,' |\
             #To stdout to proove we are doing something
-            tee scripts.txt
+             tee scripts.txt
 
